@@ -226,8 +226,8 @@ class E6xDialect(default.DefaultDialect):
     def create_connect_args(self, url):
         db = None
         _logger.info("got url query {query}".format(query=url.query))
-        if url["query"]:
-            db = url.query.split("=")[1]
+        if url.query.get("schema"):
+            db = url.query.get("schema")
         kwargs = {
             "host": url.hostname,
             "port": url.port or 10000,
